/**
 * ...
 * @author Simon, Tim
 */
 
var browserDetect = {};

/**
 * Returns if User Agent is a mobile
 * @returns Boolean - is it a mobile?
 */

browserDetect.isMobile = function() {
	return ( this.isAndroid() || this.isIOS() || this.isIEMobile() || this.isOtherMobile() || this.is2DKitBrowser() );
}

/**
 * Returns if User Agent is iOS based
 * @returns Boolean - is it a iOS?
 */
 
browserDetect.isIOS = function() {
	var ua = navigator.userAgent.toLowerCase();
	var ios = ( ua.indexOf('iphone') > -1 || ua.indexOf('ipod') > -1 || this.isIpad() );
	return ios;
}

/**
 * Returns if User Agent is iPad
 * @returns Boolean - is it an iPad?
 */
 
browserDetect.isIpad = function() {
	var ua = navigator.userAgent.toLowerCase();
	var ipad = ( ua.indexOf('ipad') > -1 || (navigator.platform === 'MacIntel' && navigator.maxTouchPoints > 1 ) );
	return ipad;
}

/**
 * IE Mobile
 */
 
browserDetect.isIEMobile = function() {
	var ua = navigator.userAgent.toLowerCase();
	return ( ua.indexOf('iemobile') > -1 );
}

/**
 * Returns if User Agent is IE7, 8, 9 or 10
 * @returns Boolean
 */
 
browserDetect.isOldIE = function() {
	var ua = navigator.userAgent.toLowerCase();
	var ie = ( ua.indexOf('msie 9') > -1 || ua.indexOf('msie 10') > -1 || ua.indexOf('msie 8') > -1 || ua.indexOf('msie 7') > -1 );
	return ie && !this.isIEMobile();
}

/**
 * Is the User agent for modern IE?
 * 
 */
 
browserDetect.isNewIE = function() {
	var ua = navigator.userAgent.toLowerCase();
	var ie = ( ua.indexOf('trident/') > -1 && ua.indexOf('edge/') == -1 );
	return ie;
}

/**
 * Is the User agent for any version of IE
 */
 
browserDetect.isIE = function() {
	return this.isNewIE() || this.isOldIE();
}

/**
 * Detect Android
 */
 
browserDetect.isAndroid = function() {
	var ua = navigator.userAgent.toLowerCase();
	var android = (ua.indexOf('android') > -1);
	return android;
}

browserDetect.isStockAndroid = function() {
	var ua = navigator.userAgent.toLowerCase();
	var other = ( ua.indexOf('chrome') > -1 || ua.indexOf('firefox') > -1 || ua.indexOf('opera') > -1 );
	return browserDetect.isAndroid() && !other;
}

browserDetect.isFacebook = function() {
	var ua = navigator.userAgent.toLowerCase();
	var fb = ( ua.indexOf("fban") > -1 || ua.indexOf("fbav") > -1 );
	return fb;
}

/* Other devices */

browserDetect.isOtherMobile = function() {
	var ua = navigator.userAgent.toLowerCase();
	var blackberry = ( ua.indexOf('blackberry') > -1 || ua.indexOf('bb10') > -1 );
	var opera_mini = ( ua.indexOf('opera mini') > -1 );
	return ( opera_mini || blackberry );
}

/**
 * Returns if device size indicates a tablet.
 * @returns Boolean - is it a tablet?
 */
 
 browserDetect.isTablet = function() {
	if ( !window.matchMedia ) {
		// old browser likely to be <=IE8
		return false;
	} else {
		return browserDetect.isMobile() && window.matchMedia("(min-device-width: 400px) and (min-device-height: 400px)").matches;
	}
}

/**
 * Returns if device size indicates a phone/ipod/other small internet enabled thing.
 * @returns Boolean - is it a phone?
 */

browserDetect.isPhone = function() {
	if ( !window.matchMedia ) {
		// old browser likely to be <=IE8
		return false;
	} else {
		return browserDetect.isMobile() && window.matchMedia("(max-device-width: 400px), (max-device-height: 400px)").matches;
	}
}

browserDetect.is2DKitBrowser = function() {
	var ua = navigator.userAgent.toLowerCase();
	return ua.indexOf("2dksim") > -1;
}