/**
 * Social wrapper for Peek & Poke Framework.
 * 
 * FB api version: 3.2
 * 
 * @author Simon, Tim
 */
 
var _tc_facebookIsReady = false;
var _tc_appIsReady = false;
var _tc_useFacebookLogin = false;
var _tc_appScope = "";
var _tc_hasRequestedReauthorise = false;
var _tc_permissionsGranted = {};
var _tc_useRedirectShare = false;
var _tc_fbAppId = "";

// Facebook has finished initialising
function tc_facebookReady() {
	_tc_facebookIsReady = true;
	if ( _tc_appIsReady && _tc_useFacebookLogin ) {
		FB.getLoginStatus( function( response ) {
			tc_checkUserStatus( false, response );
		});
	}
}

//
function tc_checkUserStatus( doLogin, response ) {
	if ( response.status === 'connected' ) {
		FB.api( "/me/permissions", function( permissions ) {
			
			//console.log( "We have permissions ", JSON.stringify( permissions ) );
			var required = _tc_appScope.split(",");
			
			// create a map of what permissions we have been granted
			_tc_permissionsGranted = {};
			for ( var i = 0; i < permissions.data.length; i++ ) {
				_tc_permissionsGranted[permissions.data[i].permissions] = (permissions.data[i].status == "granted");
			}
			
			tc_getFBUserData( );
		});
	} else {
		if ( doLogin ) tc_doFacebookLogin( _tc_appScope );
	}
}

//
function tc_doFacebookLogin( scope, reauthorise ) {
	// the user is either not logged into Facebook or hasn't authorised this app with correct permissions, so we login here
	FB.login( function( response ) {
		if ( response.authResponse ) {
			// success
			tc_getFBUserData( );
		} else {
			// failure
			console.log( "User cancelled login process or it failed somehow." );
		}
	},
	{
		scope: scope
	});	
}

function tc_getFBUserData( ) {
	FB.api('/me/?fields=id,first_name,last_name,email,name,gender,locale,picture', function( me ) {
		FB.api('/me/friends', function( friends ) {
			//console.log( JSON.stringify(me) );
			//console.log( JSON.stringify(friends) );
			// Send back to SocialProxy
			tc_internal_onFBUserDataLoaded( me, friends, _tc_permissionsGranted );
		});
	});
}

/***************************************************
 *
 * The following functions are called from the SocialProxy.
 *
 ***************************************************/

// app has loaded
function tc_appReady ( useFacebookLogin, scope ) {
	_tc_useFacebookLogin = useFacebookLogin;
	_tc_appIsReady = true;
	_tc_appScope = scope;
	if ( _tc_useFacebookLogin && _tc_facebookIsReady ) {
		FB.getLoginStatus( function( response ) {
			tc_checkUserStatus( false, response );
		});
	}
}

// Start logging in to facebook
function tc_startFacebookLogin( ) {
	FB.getLoginStatus( function( response ) {
		tc_checkUserStatus( true, response )
	});
}

// Share on FB Feed
function tc_shareOnFacebook( url ) {
	if( _tc_useRedirectShare && _tc_fbAppId != "" ) {
			var game_url = encodeURIComponent( url );
			var post_url = "https://www.facebook.com/dialog/share?app_id=" + _tc_fbAppId + "&display=page&href=" + game_url + "&redirect_uri=" + encodeURIComponent( window.location.href );
			window.location.href = post_url;
		} else {
			if( typeof FB == "object" ) {
				FB.ui({
					method: 'share',
					href: url,
				}, function ( response ) {
					if( response != null ) {
						tc_internal_onFBShared();
					}
				});
			} else {
				var game_url = encodeURIComponent( url );
				var post_url = "https://www.facebook.com/sharer/sharer.php?u=" + game_url;
				var window_options = 'menubar=no,resizable=yes,toolbar=no,location=yes,width=600,height=600';
				if ( typeof tc_internal_onFBShared == 'function' ) tc_internal_onFBShared();
				if( _tc_useRedirectShare ) {
					window.location.href = post_url;
				} else {
					window.open( post_url , 'Facebook' , window_options );
				}
			}
		}
		
}

// Share to Twitter Feed
function tc_shareOnTwitter( text, url, hashtags ) {
	var tweet_text = encodeURIComponent( text );
	var game_url = encodeURIComponent( url );
	var post_url = "https://twitter.com/intent/tweet?text=" + tweet_text + "&url=" + game_url + "&hashtags=" + hashtags;
	var window_options = 'scrollbars=yes,resizable=yes,toolbar=no,location=yes,width=600,height=300';
	if( _tc_useRedirectShare ) {
		window.location.href = post_url;
	} else {
		window.open( post_url , 'intent' , window_options );
	}
}

// Share to Google Plus
function tc_shareOnGooglePlus( url ) {
	var game_url = encodeURIComponent( url );
	var post_url = "https://plus.google.com/share?url=" + game_url;
	var window_options = 'menubar=no,resizable=yes,toolbar=no,location=yes,width=600,height=600';
	if( _tc_useRedirectShare ) {
		window.location.href = post_url;
	} else {
		window.open( post_url , 'gplus' , window_options );
	}
}

// Share to LinkedIn
function tc_shareOnLinkedIn( url ) {
	var game_url = encodeURIComponent( url );
	var post_url = "https://www.linkedin.com/shareArticle?mini=true&url=" + game_url;
	var window_options = 'menubar=no,resizable=yes,toolbar=no,location=yes,width=600,height=520';
	if( _tc_useRedirectShare ) {
		window.location.href = post_url;
	} else {
		window.open( post_url , 'linkedin' , window_options );
	}
}

// Attempt to open Email client
function tc_shareViaEmail( to, subject, body ) {
	var mail_url = "mailto:?";
	if( to ) mail_url += "to=" + encodeURIComponent( to ) + "&";
	if( subject ) mail_url += "subject=" + encodeURIComponent( subject ) + "&";
	if( body ) mail_url += "body=" + encodeURIComponent( body );
	if( _tc_useRedirectShare ) {
		window.location.href = post_url;
	} else {
		window.open( mail_url , '_blank' );
	}
}

// Attempt to open WhatsApp for sharing whatsapp://send?text=http://webdevelopmentscripts.com
function tc_shareOnWhatsApp( msg ) {
	var wa_url = "whatsapp://send?text=" + encodeURIComponent( msg );
	//if( _tc_useRedirectShare ) {
	//	window.location.href = post_url;
	//} else {
		window.open( wa_url , '_top' );
	//}
}